<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=cpf
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'access_interface_graphique' => 'Artoun si lintèrfas grafik konplé',
	'access_mode_texte' => 'Afis lintèrfas tèks sinp',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Sanz lartik-la',
	'admin_modifier_auteur' => 'Sanz linformasyon lotèr',
	'admin_modifier_breve' => 'Sanz tit-nouvèl-la',
	'admin_modifier_mot' => 'Sanz molaklé-la',
	'admin_modifier_rubrique' => 'Sanz rubrik-la',
	'admin_recalculer' => 'Arkalkil pazwèb-la',
	'afficher_trad' => 'Afich’ bann tradiksyon',
	'alerte_maj_impossible' => '<b>Tansyon !</b> Larnouvèlman labazdodné SQL zizka lo vèrsyon @version@ lé pa posib, peut-être à cause d’un problème de droit de modification sur la base de données. Veuillez contacter votre hébergeur.', # MODIF
	'alerte_modif_info_concourante' => 'ATTENTION : Cette information a été modifié par ailleurs. La valeur actuelle est :', # MODIF
	'analyse_xml' => 'Analiz XML',
	'annuler' => 'Anil’',
	'antispam_champ_vide' => 'Lés karo-la vide :',
	'articles_recents' => 'Bann zartik li lé nouvo',
	'avis_archive_incorrect' => 'Lo fisyé arsiv lé pwinn inn fisyé SPIP',
	'avis_archive_invalide' => 'Lo fisyé arsiv i giny pa marsé',
	'avis_attention' => 'TANSYON PANGAR !',
	'avis_champ_incorrect_type_objet' => 'Non d’karo-la lé fo @name@ pou inn sizé lo tip-la minm : @type@',
	'avis_colonne_inexistante' => 'Nana pwinn kolonn-la : @col@ ',
	'avis_erreur' => 'Kanard : gèt anba.',
	'avis_erreur_connexion' => 'Astèr néna inn kanard èk lakostaz.

',
	'avis_erreur_cookie' => 'Néna in larlik èk lo gatomakro (kouki)',
	'avis_erreur_fonction_contexte' => 'Astèr néna inn kanard dann program-la. Fonksyon-la, ou dwa pa apèl ali dann kontèks-la.

', # MODIF
	'avis_erreur_mysql' => 'Néna inn kanard SQL', # MODIF
	'avis_erreur_sauvegarde' => 'Astèr néna inn kanard èk la sovgard (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Kanard ék laksé privé',

	// B
	'barre_a_accent_grave' => 'Pou mèt in A èk son laksan grav an mazizkil',
	'barre_aide' => 'Pou ansèrv bann rédiyon-limprimri andan laprézantasyon dout paz',
	'barre_e_accent_aigu' => 'Pou mè in E èk son laksan égi an mazizkil',
	'barre_eo' => 'Pou mèt in E andan O',
	'barre_eo_maj' => 'Pou mèt in E andan O an mazizkil',
	'barre_euro' => 'Mèt lo sinbol €',
	'barre_gras' => 'Pou ékri {{an gro}}',
	'barre_guillemets' => 'Pou mèt bann « giymé fransé »',
	'barre_guillemets_simples' => 'Pou mè bann „giymé“',
	'barre_intertitre' => 'Mèt sa-la kom in {{{lintèrtitr}}}',
	'barre_italic' => 'Mèt sa-la an {litalik}',
	'barre_lien' => 'Mèt sa-la kom in [gatir wèb->http://...]',
	'barre_lien_input' => 'Mèrsi  indil ladrès out gatir wèb (kom in ladrès http://www.monsite/com ou sinpman èk lo niméro in lartik sit-la minm.',
	'barre_note' => 'Po sanzé an [[not anba lapaz]]',
	'barre_paragraphe' => 'Kré in paragraf',
	'barre_quote' => '<quote>Sit inn modékri</quote>',
	'bouton_changer' => 'Sanz',
	'bouton_chercher' => 'Rod',
	'bouton_choisir' => 'Swazi',
	'bouton_download' => 'Trapé', # MODIF
	'bouton_enregistrer' => 'Anrozistré',
	'bouton_radio_desactiver_messagerie_interne' => 'Dégrèn lakazmodékri',
	'bouton_radio_envoi_annonces' => 'Anvwa bann zanons léditoryal. ',
	'bouton_radio_non_envoi_annonces' => 'Anpès anvwayé bann zanons ',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Anpès anvwayé lalist bann nouvèlté',
	'bouton_recharger_page' => 'rosarz lapazwèb-la ',
	'bouton_telecharger' => 'Télésarz',
	'bouton_upload' => 'Télésarz', # MODIF
	'bouton_valider' => 'Konfirm',

	// C
	'cal_apresmidi' => 'aprémidi',
	'cal_jour_entier' => 'jou konplé',
	'cal_matin' => 'matin',
	'cal_par_jour' => 'kalandrye pa jou',
	'cal_par_mois' => 'kalandrye pa mwa',
	'cal_par_semaine' => 'kalandrye pa semèn',
	'choix_couleur_interface' => 'Koulèr',
	'choix_interface' => 'soizi lintèrfas',
	'colonne' => 'Kolonn',
	'confirm_changer_statut' => 'Pangar, ou la domann po sanz lo statu zéléman-la. Lé byin sertin y vé sanz a li ?',
	'correcte' => 'korèk',

	// D
	'date_aujourdhui' => 'zordi',
	'date_avant_jc' => 'avan J.C.',
	'date_dans' => 'dann @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'domin',
	'date_fmt_heures_minutes' => '@h@èr@m@min',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ a @heure@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
	'date_heures' => 'èr',
	'date_hier' => 'yèr',
	'date_il_y_a' => 'néna @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'dimans',
	'date_jour_1_abbr' => 'dim.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'lindi',
	'date_jour_2_abbr' => 'lin.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'mardi',
	'date_jour_3_abbr' => 'mar.',
	'date_jour_3_initiale' => 'm.',
	'date_jour_4' => 'mèrkrodi',
	'date_jour_4_abbr' => 'mèr.',
	'date_jour_4_initiale' => 'm.',
	'date_jour_5' => 'zedi',
	'date_jour_5_abbr' => 'ze.',
	'date_jour_5_initiale' => 'z.',
	'date_jour_6' => 'vandrodi',
	'date_jour_6_abbr' => 'van.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'samdi',
	'date_jour_7_abbr' => 'sam.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'bann zor',
	'date_minutes' => 'minite',
	'date_mois' => 'mwa',
	'date_mois_1' => 'zanvié',
	'date_mois_10' => 'octob',
	'date_mois_11' => 'novanm',
	'date_mois_12' => 'désanm',
	'date_mois_2' => 'févrié',
	'date_mois_3' => 'mars',
	'date_mois_4' => 'avril',
	'date_mois_5' => 'mé',
	'date_mois_6' => 'zwin',
	'date_mois_7' => 'zwiyé',
	'date_mois_8' => 'out',
	'date_mois_9' => 'séptanm',
	'date_saison_1' => 'livèrnaz an Frans - débu la grandsézon la Réinyon  ',
	'date_saison_2' => 'printan fransé - find la grandsézon /débud séson sèk la Réinyon',
	'date_saison_3' => 'été fransé - sézon sèk la Réinyon',
	'date_saison_4' => 'otonn an Frans - find sézon sèk / débu dla grandsézon la Réinyon',
	'date_semaines' => 'semèn',
	'dirs_commencer' => 'pou komans fransvérité linstalasyon ',
	'dirs_preliminaire' => 'Dabor : <b> Règ out bann drwa-laksé</b>',
	'dirs_probleme_droits' => 'Astèr, néna inn larlik èk out bann drwa-laksé',
	'dirs_repertoires_absents' => '<b>Lé pa posib giny bann répèrtwar-la : <ul>@bad_dirs@.</ul> </b>
  <p>Ni pans néna inn larlik èk lékritir bann lèt maziskil o miniskil
  Ogad byin néna okinn diskord ant bann zot maziskil o miniskil andann bann répèrtwar é sak lé afisé
  anlèr ; si ou trouv i lé pa parèy, ardonn inn ot non bann répèrtwar-la sanm out lozisyèl FTP. Komsa lo larlik i sra pou aranzé.
  <p>Kank ou lora fini ou sra kav ', # MODIF
	'dirs_repertoires_suivants' => '<b>Bann répertwar-la lé pa ouvèr pou léktritir : <ul>@bad_dirs@.</ul> </b>


<p> Anserv out kliyan FTP, pou règ bann drwa-lakostaz sir sakin


 répertwar-la. Lo guid linstalasyon i esplik aou, èk tout bann détay itil, kouk sa ou dwa fèr pou fé zwé bann drwa-la.


<p>Kank ou lora fini,i sra kav', # MODIF
	'double_occurrence' => 'Dé lokirans', # MODIF

	// E
	'envoi_via_le_site' => 'Envwa samn lo sit',
	'erreur' => 'Kanard',
	'erreur_balise_non_fermee' => 'dernyé baliz lé pa fermé :',
	'erreur_texte' => 'kanard(s)',

	// F
	'fichier_introuvable' => 'Fisyé-la @fichier@ ni pa kav trouv ali', # MODIF
	'form_deja_inscrit' => 'Ou lé déza inskri.',
	'form_email_non_valide' => 'Out ladrès imèl la pa marsé.',
	'form_forum_access_refuse' => 'Ou néna plid drwa pou akost dann sitwèb-la.',
	'form_forum_bonjour' => 'Oté @nom@,,',
	'form_forum_email_deja_enregistre' => 'Ladrès imèl-la lé déza anrozistré : ou  pé anserv modpas sa-minm sak nana labitid.',
	'form_forum_identifiant_mail' => 'Inn nouvo kod-lidentité la finn dèt anvwayé dann out kazimèl.',
	'form_forum_identifiants' => 'Out bann kod-lidantité',
	'form_forum_indiquer_nom_email' => 'Mèt isi out non èk ladrès imèl. out kod-lidantité li sava ariv talèr dann out kazimèl.',
	'form_forum_login' => 'Nondkod :',
	'form_forum_message_auto' => '(sa lé inn modékri otomatik)',
	'form_forum_pass' => 'modpas :',
	'form_forum_probleme_mail' => 'Astèr, nana inn larlik èk out imèl : lo kod-lidantité i giny pa èt anvwayé.',
	'form_forum_voici1' => 'Ala out bann kod-lidantité pou mèt ansanm ek vi lo sit"@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Ala out bann kod-lidantité pou ou i propoz bann zartik si lo sitwèb "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'Mersi inskri out ladrès imèl.',
	'form_indiquer_nom' => 'Mersi mèt isi out non.',
	'form_indiquer_nom_site' => 'Mersi mèt isi lo non out sitwèb.',
	'form_pet_deja_enregistre' => 'Sitwèb-la lé déza anrozistré',
	'form_pet_signature_pasprise' => 'Lé pa posib antyen pa out sinyatir.',
	'form_prop_confirmer_envoi' => 'Konfirm lanvwa',
	'form_prop_description' => 'Kosa i lé/arkont son lavi',
	'form_prop_enregistre' => 'Out kontribusyon lé byen arivé. Li sra disponib an liyn apré lakonfirmasyon inndé responsab lo sit.',
	'form_prop_envoyer' => 'Anvwa inn modékri',
	'form_prop_indiquer_email' => 'Mersi mèt inn ladrès imèl sak i mars',
	'form_prop_indiquer_nom_site' => 'Mersi mèt tèrla lo non lo sitwèb',
	'form_prop_indiquer_sujet' => 'Mersi indik inn sizé',
	'form_prop_message_envoye' => 'Out modékri la finn dèt anvwayé',
	'form_prop_non_enregistre' => 'Out kontribusyion lé pa anrozistré',
	'form_prop_sujet' => 'Sizé',
	'form_prop_url_site' => 'Ladrès (URL) lo sitwèb', # MODIF
	'forum_non_inscrit' => 'Ou lé pa inskri, kiswa out ladrès, kiswa out modpas nana kanardé.',
	'forum_par_auteur' => 'sanm @auteur@',
	'forum_titre_erreur' => 'Kanard...',

	// I
	'ical_texte_rss_articles' => 'Lo fisyé « backend » pou bann zartik lo sit-la, zot i va trouv ali si ladrès-la :',
	'ical_texte_rss_articles2' => 'Ou pé osi giny bann fisyé « backend » pou tout bann zartik andan ban ribrik si lo sit-la :',
	'ical_texte_rss_breves' => 'Néna in ot fisyé pou bann tite-nouvèl i sort andan lo sit. Si ou présiz lo niméro laribrik-la, i sava giny sèlman bann tite-nouvèl néna anda lo ribrik-la.',
	'icone_a_suivre' => 'Pou swiv',
	'icone_admin_site' => 'Kolonaz lo sitwèb',
	'icone_agenda' => 'Lajinda',
	'icone_aide_ligne' => 'Koudmin-wèb',
	'icone_articles' => 'Bann zartik',
	'icone_auteurs' => 'Bann lotèr',
	'icone_brouteur' => 'Bat-karé dégazé',
	'icone_configuration_site' => 'Konfigir lo sit',
	'icone_configurer_site' => 'Konfigir out sitwèb',
	'icone_creer_nouvel_auteur' => 'Kré in nouvo lotèr ',
	'icone_creer_rubrique' => 'Kré inn rubrik',
	'icone_creer_sous_rubrique' => 'Kré inn sourubrik ',
	'icone_deconnecter' => 'Défalk',
	'icone_discussions' => 'Bann kozman',
	'icone_doc_rubrique' => 'Bann dokiman dann bann rubrik',
	'icone_ecrire_article' => 'Ékri inn nouvo lartik',
	'icone_edition_site' => 'Lédisyon lo sitwèb',
	'icone_gestion_langues' => 'Po zéré bann lang',
	'icone_informations_personnelles' => 'Ladi Lafé',
	'icone_interface_complet' => 'Lintèrfas konplé',
	'icone_interface_simple' => 'Lintèrfas sinp',
	'icone_maintenance_site' => 'Lantrotyen lo sitwèb',
	'icone_messagerie_personnelle' => 'Out kazmodékri',
	'icone_repartition_debut' => 'Armontr kouk sa lé partazé dopi lorizin',
	'icone_rubriques' => 'Bann rubrik',
	'icone_sauver_site' => 'Sovgard lo sitwèb',
	'icone_site_entier' => 'Tout sitwèb sa minm',
	'icone_sites_references' => 'Inndé sitwèb référansé',
	'icone_statistiques' => 'Bann sifklé lo sitwèb',
	'icone_suivi_activite' => 'Po swiv lo vi lo sit',
	'icone_suivi_actualite' => 'Lévolisyon lo sit',
	'icone_suivi_pettions' => 'Swiv/aranz filsinyatir',
	'icone_suivi_revisions' => 'Bann sanzman do bann zartik',
	'icone_supprimer_document' => 'Dégrèn dokiman-la',
	'icone_supprimer_image' => 'Dégrèn limaz-la',
	'icone_tous_articles' => 'Tout bann zartik aou',
	'icone_tous_auteur' => 'Tout bann lotèr',
	'icone_visiter_site' => 'Bat-karé ', # MODIF
	'icone_voir_en_ligne' => 'Vwar an liyn',
	'img_indisponible' => 'zimaj-la lé pa posib giny ali',
	'impossible' => 'pa posib',
	'info_a_suivre' => 'POU SWIV »',
	'info_acces_interdit' => 'Ou néna pwinn permisyon akost lapazwèb-la.',
	'info_acces_refuse' => 'Lakostaz lapazwèb lé afronté',
	'info_action' => 'Azisman : @action@',
	'info_administrer_rubriques' => 'Ou pé zèr larubrik-la èk son bann sourubrik',
	'info_adresse_non_indiquee' => 'Ou néna pwin mi ladrès sak i vé test astèr !',
	'info_aide' => 'KOUDMIN :',
	'info_ajouter_mot' => 'Azout lo mo',
	'info_annonce' => 'ZANONS',
	'info_annonces_generales' => 'Zanons a tout moun :',
	'info_article_propose' => 'Lartik lé propozé',
	'info_article_publie' => 'Lartik lé publiyé',
	'info_article_redaction' => 'Lartik antrin lékritir ',
	'info_article_refuse' => 'Lartik lé afronté',
	'info_article_supprime' => 'Lartik lé dégréné',
	'info_articles' => 'Bann zartik',
	'info_articles_a_valider' => 'Bann zartik pou konfirmé',
	'info_articles_proposes' => 'Bann zartik sak lé propozé',
	'info_auteurs_nombre' => '(bann) lotèr :',
	'info_authentification_ftp' => 'Lotantificasyon (èk FTP).',
	'info_breves_2' => 'bann tit-nouvèl',
	'info_connexion_refusee' => 'Lakostaz lé arfizé',
	'info_contact_developpeur' => 'Mersi kontak inn dévlopèr.',
	'info_contenance' => 'Dann sit-la nana :',
	'info_contribution' => 'bann kontribusyon dann forom', # MODIF
	'info_copyright' => '@spip@ lé inn lozisyel lib sak lé doné @lien_gpl@.',
	'info_copyright_doc' => 'Pou plid zinformasyon anon vizit lo sit <a href="@spipnet@">http://www.spip.net/cpf</a>.', # MODIF
	'info_copyright_gpl' => 'sou lisans GPL',
	'info_cours_edition' => 'Out bann zartik lé apré lédisyon', # MODIF
	'info_creer_repertoire' => 'Mersi kré inn fisyé o inn répertwar èk non-la :',
	'info_creer_repertoire_2' => 'andann lo sou-répertwar <b>@repertoire@</b>, é aprè :',
	'info_creer_vignette' => 'pou kréy inn tite-limaz otomatikman',
	'info_deplier' => 'Dépliy',
	'info_descriptif_nombre' => 'Bann zafèr sak i kontyin :',
	'info_description' => 'Kosa ou va trouv isi :',
	'info_description_2' => 'Kosa ou va trouv isi :',
	'info_dimension' => 'Dimansyon :',
	'info_ecire_message_prive' => 'Pou kré inn modékri privé',
	'info_email_invalide' => 'Out ladrès imèl lé pa bon.',
	'info_en_cours_validation' => 'Out bann zartik-la lé apré lékritir',
	'info_en_ligne' => 'An liyn astèr :',
	'info_envoyer_message_prive' => 'Anvwa inn modékri privé pou lotèr-la',
	'info_erreur_requete' => 'Kanard dann rokèt-la :',
	'info_erreur_squelette2' => 'Néna pa okin léskélèt <b>@fichier@</b> sat lé disponib...',
	'info_erreur_systeme' => 'Kanar sistèm (errno @errsys@)',
	'info_erreur_systeme2' => 'Lo diksodir li sré byin po èt komplètman ragoulé o labazdodné lé gaté<br />
<span style="color:red;">Anon esayé <a href=\'@script@\'>aranzé labaz</a>, ou kontakté out lébèrzèr.</span>', # MODIF
	'info_fini' => 'Astèr sa lè fini !',
	'info_format_image' => 'Bann tay-zimaz ou pé itilizé pou kré out bann vinyèt : @gd_formats@.',
	'info_format_non_defini' => 'forma-la lé pa kadré',
	'info_grand_ecran' => 'Gran lékran',
	'info_image_aide' => 'KOUDMIN',
	'info_image_process_titre' => 'Koman ou pé kré bann tit-zimaz',
	'info_impossible_lire_page' => '<b>Kanard !</b> Lé inposib lir pazwèb-la <tt><html>@test_proxy@</html></tt> èk lo proksi <tt>', # MODIF
	'info_installation_systeme_publication' => 'Pou fé zwé (instal) lo sistèm lapiblikasyon...',
	'info_installer_documents' => 'Ou pé fè zwé otomatikman tout bann dokiman sak lé prézan dann fisyé @upload@.',
	'info_installer_ftp' => 'Kom komandèr, ou pé instal (èk FTP) bann fisyé dann dosyé @upload@ pou answuit swazi banna tèrla dirèkman.',
	'info_installer_images' => 'Ou pé fèr zwé bann zimaz èk lo forma JPEG, GIF é minm PNG.',
	'info_installer_images_dossier' => 'Instal bann zimaz dann dosyé @upload@ pou swazi azot answit, tèrla dirèkman.',
	'info_interface_complete' => 'Lintèrfas konplé',
	'info_interface_simple' => 'Lintèrfas sinp',
	'info_joindre_document_article' => 'Dann zartik-la, ou pé zwinn inndé dokiman kom',
	'info_joindre_document_rubrique' => 'Dann rubrik-la ou pé azout inndé dokiman kom',
	'info_joindre_documents_article' => 'Dann out zartik ou pé zwinn inndé dokiman kom :',
	'info_l_article' => 'lartik',
	'info_la_breve' => 'la tit-nouvèl',
	'info_la_rubrique' => 'rubrik',
	'info_langue_principale' => 'Lang prinsipal lo sitwèb',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ bann piksèl',
	'info_les_auteurs_1' => 'èk @les_auteurs@',
	'info_logo_format_interdit' => 'Lé posib mèt sèlman bann logo dann bann forma @formats@.',
	'info_logo_max_poids' => 'Fok out bann logo nena in pwa andsou @maxi@ (fichyé la li fé @actuel@).',
	'info_mail_fournisseur' => 'out@fournisèr.com',
	'info_message_2' => 'MODEKRI',
	'info_message_supprime' => 'MODÉKRI SUPRIMÉ',
	'info_mise_en_ligne' => 'Dat pou mèt an liyn :',
	'info_modification_parametres_securite' => 'bann sanzman bann paramèt lasékirité',
	'info_mois_courant' => 'Dann kouran lo mwa :',
	'info_mot_cle_ajoute' => 'Molaklé-la la finn dèt azouté dann',
	'info_multi_herit' => 'Lang laribrik anlèr',
	'info_multi_langues_soulignees' => 'Bann <u>lang soulinyé </u> lé sat néna in traidksyonkomplé po tout bann tèks lintérfas SPIP. Si ou swazi bann lang-la, néna in bon péd zéléman lo sit piblik (ladat, bann formilèr) sak i aparé tradwi otomatikman. Ek tout bann lang sat lé pa soulinyé, bann zéléamn-la i aparé samn lo lang prinsipal lo sit.', # MODIF
	'info_multilinguisme' => 'Miltilingwis',
	'info_nom_non_utilisateurs_connectes' => 'Out non lé pa visib dann fil bann zitilizatèr an liyn.',
	'info_nom_utilisateurs_connectes' => 'Out non lé vizib dann list bann zitilizatèr an liyn.',
	'info_nombre_en_ligne' => 'Astèr lé an liyn :',
	'info_non_resultat' => 'Nana pwinn rézilta pou "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Astèr i ansèrv pa lakazmodékri lo sitwèb.',
	'info_nouveau_message' => 'OU NA INN NOUVO MODÉKRI',
	'info_nouveaux_messages' => 'OU NÈNA @total_messages@ BANN MODÉKRI',
	'info_numero_abbreviation' => 'N° ',
	'info_pense_bete' => 'GARDANTÈT',
	'info_petit_ecran' => 'Tit ékran',
	'info_pixels' => 'bann piksèl',
	'info_plusieurs_mots_trouves' => 'Nana plizièr bann molaklé pou "@cherche_mot@" :',
	'info_portfolio_automatique' => 'Livzimaz otomatik :',
	'info_premier_resultat' => '[@debut_limit@ bann promyé rézilta si @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ bann promyé rézilta si @total@]',
	'info_propose_1' => '[@nom_site_spip@] i propoz aou : @titre@',
	'info_propose_2' => 'Lartik-la lé propozé
---------------',
	'info_propose_3' => 'Lartik-la, "@titre@", lé propozé pou lapiblikasyon.',
	'info_propose_4' => 'Anon zot lir ali è donn zot manyèr dvwar',
	'info_propose_5' => 'dann forom sak i bord ali. Ou va trouv ali si ladrès-la :',
	'info_publie_01' => 'Lartik "@titre@" la finn dèt konfirmé sanm @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] I PUBLIY : @titre@',
	'info_publie_2' => 'Lartik-la lé pibliyé
---------',
	'info_rechercher' => 'Rod',
	'info_rechercher_02' => 'Rod :',
	'info_remplacer_vignette' => 'Sanz lavinyèt sanswa kont out prop logo :',
	'info_sans_titre_2' => 'néna pwinn titr',
	'info_selectionner_fichier' => 'Ou i pé swazi in fisyé dann dosyé @upload@',
	'info_selectionner_fichier_2' => 'Swazi inn fisyé :',
	'info_supprimer_vignette' => 'dégrèn vinyèt-la',
	'info_symbole_bleu' => 'Lo sinbol <b>blé</b> li mark <b>inn gardantèt</b> : inn modékri pour out prop lisaz.', # MODIF
	'info_symbole_jaune' => 'Lo sinbol <b>zon</b> li mark <b>inn zanons pou tout bann lotèr</b> : banna i pé vwar ali an liyn ; bann komandèr i pé sanz ali.', # MODIF
	'info_symbole_vert' => 'Lo sinbol <b>vèr</b> i mark <b>bann modékri èk dot bann zitilizatèr</b> lo sitwèb.', # MODIF
	'info_telecharger_nouveau_logo' => 'Télésarz inn nouvo logo :',
	'info_telecharger_ordinateur' => 'Télésarz dopwi out prop lordinatèr :',
	'info_tous_resultats_enregistres' => '[tout bann rézilta la finn dèt anroziztré]',
	'info_tout_afficher' => 'Afis tout',
	'info_travaux_texte' => 'Si lo sit-la lé pa konfigiré, arvyin inn pé pli tar...',
	'info_travaux_titre' => 'Sit-la lé apré travay bèrlok  ou pètèt travay santyé...lé pa finn ankor astèr... ',
	'info_trop_resultat' => 'Nana tro bann rézilta pou "@cherche_mot@" ; mersi kadr myé lo rodaz.',
	'info_utilisation_messagerie_interne' => 'Ou ansèrv lakazmodékri lo sitwèb.',
	'info_valider_lien' => 'konfirm gatir-la',
	'info_verifier_image' => ', mersi gèt ankor out bann zimaz la finn dèt sarzé korèkman sir lo servèr.',
	'info_vignette_defaut' => 'Vinyèt sanswa',
	'info_vignette_personnalisee' => 'Out prop vinyèt',
	'info_visite' => 'vizit :',
	'info_vos_rendez_vous' => 'Out bann prosin randévou',
	'infos_vos_pense_bete' => 'Out bann gardantèt', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Afis sèlman bann zikon',
	'lien_afficher_texte_icones' => 'Afis bann zikon èk lo tèks',
	'lien_afficher_texte_seul' => 'Afis sèlman lo tèks',
	'lien_liberer' => 'Maronn',
	'lien_liberer_tous' => 'maronn tout bann zartik-la', # MODIF
	'lien_nouvea_pense_bete' => 'NOUVO GARDANTÈT',
	'lien_nouveau_message' => 'NOUVO MODÉKRI',
	'lien_nouvelle_annonce' => 'NOUVEL ZANONS',
	'lien_petitions' => 'FILSINYATIR',
	'lien_popularite' => 'Koman lé populèr : @popularite@%',
	'lien_racine_site' => 'RASIN LO SITWÈB',
	'lien_reessayer' => 'ésèy ankor',
	'lien_repondre_message' => 'Réponn modékri-la',
	'lien_supprimer' => 'dégrèn',
	'lien_tout_afficher' => 'Afis tout',
	'lien_visite_site' => 'vizit lo sit-la',
	'lien_visites' => '@visites@ bann vizit',
	'lien_voir_auteur' => 'Gèt lotèr-la',
	'login_acces_prive' => 'laksé pou léspas privé',
	'login_autre_identifiant' => 'Akost lo sit èk inn nouvèl nondkod',
	'login_cookie_accepte' => 'Mersi règl a zot navigatèr pou li asèpt azot (mwindreman pou sitwèb-la).',
	'login_cookie_oblige' => 'Pou inn lidantifikasyon sir si lo sit, ou dwa asépté bann gatomakro.',
	'login_deconnexion_ok' => 'Out défalkaz la finn marsé.',
	'login_erreur_pass' => 'Kanard èk lo modpas.',
	'login_espace_prive' => 'Léspas privé',
	'login_identifiant_inconnu' => 'Lo nondkod « @login@ » li lé pa konu.',
	'login_login' => 'Nondkod :',
	'login_login2' => 'Nondkod (lidantifian pou lakostaz lo sitwèb) :', # MODIF
	'login_login_pass_incorrect' => '(Out nondkod ou modpas lé pa korèk.)',
	'login_motpasseoublie' => 'Ou la oubliyé out modpas ?',
	'login_non_securise' => 'Tansyon pangar, formulèr-la lé pa sékirizé.
Si ou vé pa person i atrap out modpass si lo rézo
mersi fé zwé lo Javascript 
dann out navigatèr é',
	'login_nouvelle_tentative' => 'Nouvèl ésé',
	'login_par_ici' => 'Ou lé anroziztré... dann kwin-la...',
	'login_pass2' => 'Modpas :',
	'login_preferez_refuser' => '<b>Si ou préfèr afront bann gatomakro</b>,nana inn ot sistèm lakostaz (mwin sir) sak ou pé anserv :',
	'login_recharger' => 'rosarz pazwèb-la',
	'login_rester_identifie' => 'Po inn lidantifikasyon i dir plisyèr zor', # MODIF
	'login_retour_public' => 'Artourn sir figirwèb',
	'login_retour_site' => 'Artourn sir figirwèb',
	'login_retoursitepublic' => 'artourn sir figirwèb',
	'login_sinscrire' => 'inskri aou',
	'login_test_navigateur' => 'test navigatèr/nouvo lakostaz',
	'login_verifiez_navigateur' => '(Somansa gét byin out navigatèr la pa gardantèt out modpass...)',

	// M
	'module_fichiers_langues' => 'Bann fisyé lang',

	// N
	'navigateur_pas_redirige' => 'Si out navigatèr lé pa rotourné, apiy tèrla pou kontinyé.',

	// O
	'onglet_affacer_base' => 'Dégrèn labazdodné',
	'onglet_auteur' => 'Lotèr',
	'onglet_contenu_site' => 'Sak lo sit i kontyin',
	'onglet_evolution_visite_mod' => 'Sanzman',
	'onglet_fonctions_avances' => 'Bann fonksyon présiz',
	'onglet_informations_personnelles' => 'Bann zinformasyon lotèr',
	'onglet_interactivite' => 'Kozantrozot',
	'onglet_messagerie' => 'Kazmodékri',
	'onglet_repartition_rubrique' => 'Partaz sanm rubrik',
	'onglet_save_restaur_base' => 'Sovgard/rosarz léta labaz',
	'onglet_vider_cache' => 'Dévid lo kas',

	// P
	'pass_choix_pass' => 'Mersi swazi out nouvo modpas :',
	'pass_erreur' => 'Kanard',
	'pass_erreur_acces_refuse' => '<b>Kanard :</b> out nana pli laksé sir lo sit-la.',
	'pass_erreur_code_inconnu' => '<b>Kanard :</b> lo kod-la i korespon pa pou okin lotèr anroziztré si lo sit.',
	'pass_erreur_non_enregistre' => '<b>Kanard :</b> ladrès-la <tt>@email_oubli@</tt> li lé pli anroziztré si lo sit-la.',
	'pass_erreur_non_valide' => '<b>Kanard : /b> limèl-la <tt>@email_oubli@</tt> lé pa bon !',
	'pass_erreur_probleme_technique' => '<b>Kanard :</b> akoz inn larlik tèknik, lé pa posib astèr anvwayé limèl-la.',
	'pass_espace_prive_bla' => 'Léspas privé lo sit-la lé ouvèr pou tout
bann vizitèr, aprè linskrisyon. Kank ou lé anroziztré,
i pé konsilt oubyinsa propoz bann zartik.I pé osi
mèt ansanm èk bann dalon dan tout bann forom.',
	'pass_forum_bla' => 'Ou la domand mèt out grindsèl dann forom
sak lé rézèrvé pou bann vizitèr anrozistré.',
	'pass_indiquez_cidessous' => 'Mèt isi ladrès imèl ou la déza anservi pou anroziztr aou. Aprésa, ou sava
giny inn limèl : li indik aou lamanyir pou rékupèr out laksé.',
	'pass_mail_passcookie' => '(Sa lé in modékri otomatik)
Pour ou i pé artrouv out laksé si lo sitwèb
@nom_site_spip@ (@adresse_site@)

Mersi rand aou sir ladrès la :
    @sendcookie@

Aprésa, ou i poura mèt in nouvo modpas
 pou rakost lo sitwèb.
',
	'pass_mot_oublie' => 'Modpas oubliyé',
	'pass_nouveau_enregistre' => 'Out nouvo modpas la fin dèt anroziztré.',
	'pass_nouveau_pass' => 'Nouvo modpas',
	'pass_ok' => 'Dakor',
	'pass_oubli_mot' => 'Modpas oublyé',
	'pass_quitter_fenetre' => 'Défalk finèt-la',
	'pass_rappel_login' => 'Rapèl aou : out lidantifyan (nondkod) lé « @login@ ».',
	'pass_recevoir_mail' => 'Ou sava giny inn limèl sak i indik aou kouk sa i pé artrouv out laksé sir lo sit.', # MODIF
	'pass_retour_public' => 'Artourn sir figirwèb',
	'pass_rien_a_faire_ici' => 'Nana ryinn a fèr isi.',
	'pass_vousinscrire' => 'Inskri aou sir lo sit',
	'precedent' => 'dovan',
	'previsualisation' => 'Po vwar avann komsi lé an liny',
	'previsualiser' => 'Po vwar avan',

	// S
	'squelette' => 'léskelèt',
	'squelette_inclus_ligne' => 'leskélèt dodan, liny',
	'squelette_ligne' => 'léskelèt, liny',
	'stats_visites_et_popularite' => '@visites@ vizit ; popularité : @popularite@',
	'suivant' => 'dèryèr',

	// T
	'taille_ko' => '@taille@ ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ bann zokté',
	'texte_actualite_site_1' => 'Kank ou sra pli zabityé èk lo figirwèb, i poura klik sir « ',
	'texte_actualite_site_2' => 'lintèrfas konplé',
	'texte_actualite_site_3' => ' » pour giny plid posibilité.',
	'texte_creation_automatique_vignette' => 'Lakréasyon otomatik pou bann vinyèt avwar-avan, lé an mars si lo sit-la. Si ou linstal bann zimaz dann (bann) tay  @gd_formats@, dopwi formulèr-la, zimaz-la i sra prézanté èk inn vinyèt pa pli grank @taille_preview@ bann piksèl oplis.',
	'texte_documents_associes' => 'Bann dokiman-la lé mi èk lartik-la,
mé zot lé pa plasé dann kor-minm lartik-la. Sélon lamanyir ou sava mèt an paz lo sit piblik,
zot i sra pou aparèt kom bann dokiman zwinn.',
	'texte_erreur_mise_niveau_base' => 'Kanard do bazdodné dann tan larmizanivo .
Limaz <b>@fichier@</b> la pa pasé dann (article @id_article@).
Gard byin an tèt référans-la, ésèy inn ot fwa inn larmizanivo, é véy byin sak bann zimaz i aparé touzour dann bann zartik.', # MODIF
	'texte_inc_auth_1' => 'Ou lé konu sir lo sit èk lo
 nondkod <b>@auth_login@</b>, mé li lé pa/pli prézan astèr dann labaz. 
Esèy', # MODIF
	'texte_inc_auth_2' => 'rakost inn ot fwa',
	'texte_inc_auth_3' => 'apré ou la petèt sort èk ardémar out
navigatèr.',
	'texte_inc_config' => 'Bann sanzman sir bann paz-la na inn léfé importan sir lamanyir
out sit i mars. Ni konsèy aou pa tous a ryin si ou lé pa fransvérité byin abityé èk lo sistèm SPIP.

 <br /><br /><b>É minm, ni konséy
aou lès lazéstyon do bann paz-la pou lo wèbmèt prinsipal.</b>', # MODIF
	'texte_inc_meta_1' => 'Sistèm-la la finn trové inn larlik èk lékritir lo fisyé <code>@fichier@</code>.  Mersi, kom komandèr lo sit,',
	'texte_inc_meta_2' => 'vérifyé bann drwa lékritir',
	'texte_inc_meta_3' => 'dann répertwar <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'apré lékritir',
	'texte_statut_poubelle' => 'dann korbèy',
	'texte_statut_propose_evaluation' => 'propozé pou zot zizman',
	'texte_statut_publie' => 'pibliyé an liyn',
	'texte_statut_refuse' => 'arfizé',
	'titre_ajouter_mot_cle' => 'AZOUT INN MOLAKLÉ :',
	'titre_cadre_raccourcis' => 'BANN RÉDIYON :',
	'titre_changer_couleur_interface' => 'Sanz lakoulèr lintèrfas',
	'titre_image_admin_article' => 'Ou pé zèr lartik-la',
	'titre_image_administrateur' => 'Komandèr',
	'titre_image_aide' => 'Koudmin sir léléman-la',
	'titre_image_auteur_supprime' => 'Lotèr lé dégréné',
	'titre_image_redacteur' => 'Lotèr san laksé',
	'titre_image_redacteur_02' => 'Lotèr',
	'titre_image_visiteur' => 'Vizitèr',
	'titre_joindre_document' => 'POU ZWIND INN DOKIMAN',
	'titre_mots_cles' => 'BANN MOLAKLÉ',
	'titre_probleme_technique' => 'Pangar : inn larlik tèknik (servèr SQL) i défann permisyon lakostaz dan landrwa la. Éskiz anou.', # MODIF
	'titre_publier_document' => 'PUBLIY INN DOKIMAN DANN RUBRIK-LA',
	'titre_statistiques' => 'Sifklé lo sitwèb',
	'titre_titre_document' => 'Lo non dokiman-la :',
	'trad_reference' => '(Lartik-péi de référans)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : baliz B anlèr',
	'zbug_balise_inexistante' => 'erreur @from@ : la balise #@balise@ n’existe pas', # MODIF
	'zbug_boucle' => 'boukl',
	'zbug_boucle_recursive_undef' => 'boukl rékirsiv-la lé pa défini', # MODIF
	'zbug_champ_hors_boucle' => 'lo chan @champ@ lé andéor in boukl',
	'zbug_champ_hors_motif' => 'Lo chan @champ@ lé an déor in boukl-motif @motif@', # MODIF
	'zbug_code' => 'kod',
	'zbug_critere_inconnu' => 'kritèr-la lé pa konu @critere@', # MODIF
	'zbug_distant_interdit' => 'déor interdi', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
	'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
	'zbug_erreur_boucle_double' => 'BOUCLE@id@ : néna dé définisyon', # MODIF
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@ : néna in "tag" sat i mank po tak in boukl.', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Sintask lo boukl-là lé pa korèk', # MODIF
	'zbug_erreur_execution_page' => 'néna in larlik pou léxékisyon paj-la', # MODIF
	'zbug_erreur_filtre' => 'Néna in kanar andan lo filt <b>« @filtre@ »</b> sat lé pa défini', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} li aplik sèlman pou bann boukl (FORUMS) ou (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'néna (bann) larlik andan léskélèt',
	'zbug_info_erreur_squelette' => 'Kanar sir lo sit',
	'zbug_inversion_ordre_inexistant' => 'lord existan lé inversè', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION sans critère {pagination} ou employé dans une boucle recursive', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Bann paramèt pou linklizyon lé pa korèk', # MODIF
	'zbug_resultat' => 'rézilta',
	'zbug_serveur_indefini' => 'servèr SQL la lé pa défini', # MODIF
	'zbug_table_inconnue' => 'Lo tab SQL « @table@ »  la , li lé pa konu'
);
